# Knowledge Graphs at AAAI 2020

## KRL
__Rule-Guided Compositional Representation Learning on Knowledge Graphs__
AAAI 2020. _Niu et al._ [[Paper](https://arxiv.org/pdf/1911.08935.pdf)]

__Triple2Vec: Learning Triple Embeddings from Knowledge Graphs__.
AAAI 2020. _Fionda et al._ [[Paper](https://arxiv.org/pdf/1905.11691)]

__InteractE: Improving Convolution-based Knowledge Graph Embeddings by Increasing Feature Interactions__
AAAI 2020. _Vashishth et al._ [[Paper](https://arxiv.org/pdf/1911.00219)] [[Code](https://github.com/malllabiisc/InteractE)]

## KGC
__Few-Shot Knowledge Graph Completion__.
AAAI 2020. _Zhang et al._ [[Paper](https://arxiv.org/pdf/1911.11298)]


__Learning Hierarchy-Aware Knowledge Graph Embeddings for Link Prediction__ 
AAAI 2020. _Zhang et al._ [[Paper](https://arxiv.org/pdf/1911.09419.pdf)]
> HAKE, Hierarchy-Aware Knowledge Embedding; capture semantic hierarchies; map entities into the polar coordinate system; radial coordinate for representing levels of the hierarchy and angular coordinate for distinguishing entities at the same level of hierarchy

__Commonsense Knowledge Base Completion with Structural and Semantic Context__
AAAI 2020. _Malaviya et al._. [[Paper](https://arxiv.org/pdf/1910.02915.pdf)] 

__Understanding the semantic content of sparse word embeddings using a commonsense knowledge base__
AAAI 2020 Workshop. [[Paper](https://kr2ml.github.io/2019/papers/KR2ML_2019_paper_29.pdf)]

__Relational Graph Neural Network with Hierarchical Attention for Knowledge Graph Completion__
AAAI 2020. _Zhang et al._. [[Paper](https://www.aaai.org/Papers/AAAI/2020GB/AAAI-ZhangZ.6756.pdf)]
> encoder-decoder framework, hierarchically attentive graph encoder

__Contextual Parameter Generation for Knowledge Graph Link Prediction__.
AAAI 2020. _Stoica et al._. [[Paper](https://platanios.org/assets/pdf/platanios_2020_coper/paper.pdf)] [[Paper](https://github.com/otiliastr/coper)]

__Diachronic Embedding for Temporal Knowledge Graph Completion__.
AAAI 2020. _Goel et al._. [[Paper](https://arxiv.org/pdf/1907.03143)] [[Code](https://github.com/BorealisAI/de-simple)]

## Relation Extraction
__Are Noisy Sentences Useless for Distant Supervised Relation Extraction?__
AAAI 2020. _Shang et al._. [[Paper](https://arxiv.org/pdf/1911.09788)]

__Self-Attention Enhanced Selective Gate with Entity-Aware Embedding for Distantly Supervised Relation Extraction__
AAAI 2020. _Li et al._ [[Paper](https://arxiv.org/pdf/1911.11899.pdf)]

## Entity Alignment
__Knowledge Graph Alignment Network with Gated Multi-hop Neighborhood Aggregation__
AAAI 2020. _Zequn Sun, Chengming Wang, Wei Hu1, Muhao Chen, Jian Dai, Wei Zhang, Yuzhong Qu_
[[Paper](https://arxiv.org/pdf/1911.08936.pdf)] [[Code](https://github.com/nju-websoft/AliNet)]
> AliNet to mitigate the non-isomorphism of neighborhood structures  
> graph neural networks, attention, a relation loss to refine entity representations 

__Coordinated Reasoning for Cross-Lingual Knowledge Graph Alignment__. 
AAAI 2020. _Xu et al._. [[Paper](https://arxiv.org/pdf/2001.08728)] 

## Entity Linking
__LATTE: Latent Type Modeling for Biomedical Entity Linking__
AAAI 2020. _Zhu et al._. [[Paper](https://arxiv.org/pdf/1911.09787.pdf)]

__Improving Entity Linking by Modeling Latent Entity Type Information__
AAAI 2020. _Chen et al._ [[Paper](https://arxiv.org/pdf/2001.01447)]

## Named Entity Recognition
__Leveraging Multi-token Entities in Document-level Named Entity Recognition__
AAAI 2020. _Hu et al._ [[Paper](http://playbigdata.ruc.edu.cn/dou/publication/2020_aaai_ner.pdf)]

__Robust Named Entity Recognition with Truecasing Pretraining__. 
AAAI 2020. _Mayhew et al._ [[Paper](https://arxiv.org/pdf/1912.07095)]

## Meta Relational Learning
__Generative Adversarial Zero-Shot Relational Learning for Knowledge Graphs__
AAAI 2020. _Qin et al_. [[Paper](https://arxiv.org/pdf/2001.02332.pdf)]


## Natural Language Understanding
__Evaluating Commonsense in Pre-trained Language Models__
AAAI 2020. _Zhou et al._ 
[[Paper](https://arxiv.org/pdf/1911.11931.pdf)] [[Code & Dataset](https://github.com/XuhuiZhou/CATS)]
> study the commonsense ability of GPT, BERT, XLNet, and RoBERTa
> test the robustness of models by making dual test cases

__Latent Relation Language Models__.
AAAI 2020. _Hayashi et al._ [[Paper](https://arxiv.org/abs/1908.07690)]
> LRLM parameterizes the joint distribution over the words in a document
> annotate the posterior probability of entity spans for a given text through relations

__K-BERT: enabling language representation with knowledge graph__
AAAI 2020. _Liu et al._ [[Paper](https://arxiv.org/pdf/1909.07606.pdf)] [[Code](https://github.com/autoliuweijie/K-BERT)]
> K-BERT, Knowledge-enabled Bidirectional Encoder Representation from Transformers
> Method: injecting triples into sentences, soft-position and visible matrix to overcome knowledge noise  
> Task: Chinese NLP, open-domain and specific-domain tasks  


__Differentiable Reasoning on Large Knowledge Bases and Natural Language__
AAAI 2020. _Minervini et al._ [[Paper](https://arxiv.org/abs/1912.10824)]
> GNTP, Greedy Neural Theorem Provers  
> Idea: extend NTPs to address their complexity and scalability limitation, reducing the number of candidate proof paths and introducing an attention mechanism for rule induction   
> Task: link prediction

__Reasoning on Knowledge Graphs using Debate Dynamics__
AAAI 2020. _Hildebrandt et al._ [[Paper](https://arxiv.org/pdf/2001.00461.pdf)] [[Code](https://github.com/m-hildebrandt/R2D2)]
> R2D2 (Reveal Relations using Debate Dynamics)  
> Task: triple classification   
> Idea: triple classification as a debate game between two RL agents extracting relational paths as arguments  
> Method: reinforcement learning, a binary classifier judges the factual triples as thesis or antithesis

__Knowledge Graph Grounded Goal Planning for Open-Domain Conversation Generation__
AAAI 2020. _Xu et al._. [[Paper](http://ir.hit.edu.cn/~car/papers/AAAI2020-Xu-kg.pdf)]

__Towards Scalable Multi-Domain Conversational Agents:The Schema-Guided Dialogue Dataset__.
AAAI 2020. _Rastogi et al._ [[Paper](https://arxiv.org/abs/1909.05855)]


## Computer Vision
__Knowledge Graph Transfer Network for Few-Shot Recognition__
AAAI 2020. _Chen et al._. [[Paper](https://arxiv.org/pdf/1911.09579)]